@@ -15,8 +15,6 @@
 
 #include <net/ethernet.h>
 
-#include <libnotify/notify.h>
-
 #ifdef WITH_APPINDICATOR
 #if USE_AYATANA_INDICATORS
 #include <libayatana-appindicator/app-indicator.h>
@@ -115,6 +113,7 @@ typedef struct {
 	/* Direct UI elements */
 #ifdef WITH_APPINDICATOR
 	AppIndicator *  app_indicator;
+	bool            app_indicator_show_signal_received;
 #endif
 	guint           update_menu_id;
 
@@ -137,7 +136,6 @@ typedef struct {
 	GtkWidget *     connections_menu_item;
 
 	GtkBuilder *    info_dialog_ui;
-	NotifyNotification* notification;
 
 	/* Tracker objects for secrets requests */
 	GSList *        secrets_reqs;
@@ -185,7 +183,7 @@ struct NMADeviceClass {
 	                                        AppletNewAutoConnectionCallback callback,
 	                                        gpointer callback_data);
 
-	void           (*add_menu_item)        (NMDevice *device,
+	gboolean       (*add_menu_item)        (NMDevice *device,
 	                                        gboolean multiple_devices,
 	                                        const GPtrArray *connections,
 	                                        NMConnection *active,
@@ -260,20 +258,10 @@ NMRemoteConnection *applet_get_exported_connection_for_device (NMDevice *device,
 NMDevice *applet_get_device_for_connection (NMApplet *applet, NMConnection *connection);
 
 void applet_do_notify (NMApplet *applet,
-                       NotifyUrgency urgency,
-                       const char *summary,
-                       const char *message,
-                       const char *icon,
-                       const char *action1,
-                       const char *action1_label,
-                       NotifyActionCallback action1_cb,
-                       gpointer action1_user_data);
-
-void applet_do_notify_with_pref (NMApplet *applet,
-                                 const char *summary,
-                                 const char *message,
-                                 const char *icon,
-                                 const char *pref);
+                       const char *title,
+                       const char *body,
+                       const char *icon_name,
+                       const char *pref);
 
 GtkWidget * applet_new_menu_item_helper (NMConnection *connection,
                                          NMConnection *active,
