@@ -60,6 +60,12 @@ finish_setup (CEPageVpn *self, gpointer user_data)
 		g_warning ("Could not load VPN user interface for service '%s'.", priv->service_type);
 		return;
 	}
+
+	gtk_widget_set_margin_top (parent->page, 12);
+	gtk_widget_set_margin_bottom (parent->page, 12);
+	gtk_widget_set_margin_left (parent->page, 12);
+	gtk_widget_set_margin_right (parent->page, 12);
+
 	g_object_ref_sink (parent->page);
 	gtk_widget_show_all (parent->page);
 }
